@@ -5,8 +5,8 @@ Contains functions associated with evolving the equations of motion.
 from typing import Callable
 
 import numpy as np
-import pygsl.errno as errno
-import pygsl.odeiv2 as odeiv2
+import pygsl_lite.errno as errno
+import pygsl_lite.odeiv2 as odeiv2
 from numba import *
 from numba import jit, types
 
@@ -14,19 +14,26 @@ from ..fits.fits_Hamiltonian import dSO as dSO_poly_fit
 from ..hamiltonian import Hamiltonian
 from ..utils.math_ops_opt import *
 from .initial_conditions_aligned_precessing import computeIC_augm
-from .pn_evolution_opt import rhs_wrapper,compute_omega_orb,compute_quasiprecessing_PNdynamics_opt,build_splines_PN
+from .pn_evolution_opt import (
+    rhs_wrapper,
+    compute_omega_orb,
+    compute_quasiprecessing_PNdynamics_opt,
+    build_splines_PN,
+)
 from .integrate_ode import interpolate_dynamics, iterative_refinement
 from ..utils.containers import EOBParams
 from ..utils.math_ops_opt import my_norm
+
 # Test cythonization of PN equations
 
 from scipy.interpolate import CubicSpline
 from scipy.signal import argrelmin
 
 
-step = odeiv2.pygsl_odeiv2_step
-_control = odeiv2.pygsl_odeiv2_control
-evolve = odeiv2.pygsl_odeiv2_evolve
+step = odeiv2.pygsl_lite_odeiv2_step
+_control = odeiv2.pygsl_lite_odeiv2_control
+evolve = odeiv2.pygsl_lite_odeiv2_evolve
+
 
 class control_y_new(_control):
     def __init__(self, eps_abs, eps_rel):
@@ -34,6 +41,7 @@ class control_y_new(_control):
         a_dydt = 1
         _control.__init__(self, eps_abs, eps_rel, a_y, a_dydt, None)
 
+
 # Function to terminate the EOB evolution
 def check_terminal(
     r: float,
@@ -44,7 +52,7 @@ def check_terminal(
     omega_previous: float,
     r_previous: float,
     omegaPN_f: float,
-    )->int :
+) -> int:
     """
     Check termination condition of the EOB evolution.
 
@@ -63,37 +71,37 @@ def check_terminal(
     """
 
     if r <= 1.4:
-        #print(f"r = {r} < 1.4, omega = {omega}")
+        # print(f"r = {r} < 1.4, omega = {omega}")
         return 1
 
     if np.isnan(omega) or np.isnan(drdt) or np.isnan(dprdt) or np.isnan(omega_circ):
-        #print(f"nan omega: r = {r}, omega = {omega}")
+        # print(f"nan omega: r = {r}, omega = {omega}")
         return 2
 
     if omega < omega_previous:
-        #print(f"r = {r}, omega = {omega}, omega_previous = {omega_previous}")
+        # print(f"r = {r}, omega = {omega}, omega_previous = {omega_previous}")
         return 3
 
     if r < 3:
 
-        if drdt >0:
-            #print(f"drdt>0 : r = {r}, omega = {omega}, omega_previous = {omega_previous}")
+        if drdt > 0:
+            # print(f"drdt>0 : r = {r}, omega = {omega}, omega_previous = {omega_previous}")
             return 5
 
-        if dprdt >0:
-            #print(f"dprdt >0 : r = {r}, omega = {omega}, omega_previous = {omega_previous}")
+        if dprdt > 0:
+            # print(f"dprdt >0 : r = {r}, omega = {omega}, omega_previous = {omega_previous}")
             return 6
 
         if omega_circ > 1:
-            #print(f"omega_circ >1 : r = {r}, omega = {omega}, omega_previous = {omega_previous}")
+            # print(f"omega_circ >1 : r = {r}, omega = {omega}, omega_previous = {omega_previous}")
             return 7
 
         if r > r_previous:
-            #print(f"r> r_previous : r = {r}, omega = {omega}, omega_previous = {omega_previous}, r_previous = {r_previous}")
+            # print(f"r> r_previous : r = {r}, omega = {omega}, omega_previous = {omega_previous}, r_previous = {r_previous}")
             return 8
 
     if omega > omegaPN_f:
-        #print(f"omega> omegaPN_f : r = {r}, omega = {omega}, omegaPN_f = {omegaPN_f}")
+        # print(f"omega> omegaPN_f : r = {r}, omega = {omega}, omegaPN_f = {omegaPN_f}")
         return 9
 
     return 0
@@ -102,7 +110,7 @@ def check_terminal(
 def compute_dynamics_prec_opt(
     omega_ref: float,
     omega_start: float,
-    omegaPN_f:float,
+    omegaPN_f: float,
     H: Hamiltonian,
     RR: Callable,
     m_1: float,
@@ -113,11 +121,11 @@ def compute_dynamics_prec_opt(
     params: EOBParams,
     rtol: float = 1e-12,
     atol: float = 1e-12,
-    step_back: float = 250.,
+    step_back: float = 250.0,
     y_init=None,
-    initial_conditions: str = 'adiabatic',
-    initial_conditions_postadiabatic_type: str = 'analytic',
-    ):
+    initial_conditions: str = "adiabatic",
+    initial_conditions_postadiabatic_type: str = "analytic",
+):
     """
     Function to perform a non-precessing EOB evolution with the spins modified
     at every timestep according to the values from the precessing-spin PN
@@ -150,7 +158,6 @@ def compute_dynamics_prec_opt(
 
     # Step 3 : Evolve EOB dynamics
 
-
     # Step 3.1) Update spin parameters and calibration coeffs (only dSO) at the start of EOB integration
 
     X1 = params.p_params.X_1
@@ -179,7 +186,6 @@ def compute_dynamics_prec_opt(
     dSO_start = dSO_poly_fit(params.p_params.nu, ap_start, am_start)
     H.calibration_coeffs["dSO"] = dSO_start
 
-
     # Step 3.2: compute the initial conditions - uses the aligned-spin ID
     if y_init is None:
         if initial_conditions == "adiabatic":
@@ -202,8 +208,10 @@ def compute_dynamics_prec_opt(
                 omega_start,
                 H,
                 RR,
-                chi1_v_start, chi2_v_start,
-                m_1, m_2,
+                chi1_v_start,
+                chi2_v_start,
+                m_1,
+                m_2,
                 splines,
                 t_pn,
                 dynamics_pn,
@@ -212,13 +220,11 @@ def compute_dynamics_prec_opt(
             )
         y0 = np.array([r0, 0.0, pr0, pphi0])
 
-
     else:
 
         y0 = y_init.copy()
         r0 = y0[0]
 
-
     # Step 3.3: now integrate the dynamics
     sys = odeiv2.system(rhs_wrapper, None, 4, [H, RR, m_1, m_2, params])
 
@@ -233,7 +239,7 @@ def compute_dynamics_prec_opt(
     y = y0
 
     if y_init is None:
-        h = 2 * np.pi / omega_start / 100.
+        h = 2 * np.pi / omega_start / 100.0
     else:
         h = 0.1
 
@@ -245,23 +251,28 @@ def compute_dynamics_prec_opt(
     augm_dyn = []
 
     # Convert to numpy array to get the correct value
-    augm_dyn.append([params.p_params.H_val, params.p_params.omega, params.p_params.omega_circ, params.p_params.chi_1, params.p_params.chi_2])
+    augm_dyn.append(
+        [
+            params.p_params.H_val,
+            params.p_params.omega,
+            params.p_params.omega_circ,
+            params.p_params.chi_1,
+            params.p_params.chi_2,
+        ]
+    )
     ts.append(0.0)
     res_gsl.append(y)
     omegas.append(params.p_params.omega)
 
-
     omega_previous = omega_start
     r_previous = r0
 
     X1 = params.p_params.X_1
     X2 = params.p_params.X_2
 
-
     peak_omega = False
     peak_pr = False
 
-
     while t < t1:
 
         # Take a step
@@ -274,16 +285,22 @@ def compute_dynamics_prec_opt(
 
         r = y[0]
 
-
         if np.isnan(r):
-            #print(f"t = {t}, r = {r}, h = {h}")
+            # print(f"t = {t}, r = {r}, h = {h}")
             break
         else:
             # Append the last step
             res_gsl.append(y)
             ts.append(t)
-            augm_dyn.append([params.p_params.H_val, params.p_params.omega, params.p_params.omega_circ, params.p_params.chi_1, params.p_params.chi_2])
-
+            augm_dyn.append(
+                [
+                    params.p_params.H_val,
+                    params.p_params.omega,
+                    params.p_params.omega_circ,
+                    params.p_params.chi_1,
+                    params.p_params.chi_2,
+                ]
+            )
 
         # Handle termination conditions
         if r <= 6:
@@ -305,7 +322,9 @@ def compute_dynamics_prec_opt(
                 omega_circ = params.p_params.omega_circ
 
             # check termination conditions
-            termination = check_terminal(r, omega, drdt, dprdt, omega_circ, omega_previous, r_previous, omegaPN_f)
+            termination = check_terminal(
+                r, omega, drdt, dprdt, omega_circ, omega_previous, r_previous, omegaPN_f
+            )
             if termination:
                 if termination == 3:
                     peak_omega = True
@@ -319,7 +338,6 @@ def compute_dynamics_prec_opt(
             omega = compute_omega_orb(t, y, H, RR, m_1, m_2, params)
             omegas.append(omega)
 
-
         # Update spin parameters and calibration coeffs (only dSO)
         params.p_params.omega = omega
         omega_circ = params.p_params.omega_circ
@@ -336,14 +354,14 @@ def compute_dynamics_prec_opt(
 
         params.p_params.chi1_v[:] = chi1_v
         params.p_params.chi2_v[:] = chi2_v
-        #params.p_params.lN[:] = tmp_LN#/my_norm(tmp_LN)
+        # params.p_params.lN[:] = tmp_LN#/my_norm(tmp_LN)
 
         ap = chi1_LN * X1 + chi2_LN * X2
         am = chi1_LN * X1 - chi2_LN * X2
 
         # Check for possible extrapolation in the spin values
-        if abs(ap)>1 or abs(am)>1:
-            #print(f"r = {r}, omega = {omega}, ap = {ap}, am = {am}")
+        if abs(ap) > 1 or abs(am) > 1:
+            # print(f"r = {r}, omega = {omega}, ap = {ap}, am = {am}")
             break
 
         dSO_new = dSO_poly_fit(params.p_params.nu, ap, am)
@@ -355,11 +373,9 @@ def compute_dynamics_prec_opt(
         params.p_params.chi1_L = chi1_L
         params.p_params.chi2_L = chi2_L
 
-
         # Remember to update the derived spin quantities which enter the flux
         params.p_params.update_spins(params.p_params.chi_1, params.p_params.chi_2)
 
-
     # Step 3.4: After the integration assemble quantities and apply a roll-off of the timestep
     #           to avoid abrupt changes in the splines
     ts = np.array(ts)
@@ -367,7 +383,7 @@ def compute_dynamics_prec_opt(
     omega_eob = np.array(omegas)
     augm_dyn = np.array(augm_dyn)
 
-    dyn = np.c_[dyn,augm_dyn]
+    dyn = np.c_[dyn, augm_dyn]
 
     # Step 3.5: Iterative procedure to find the peak of omega or pr to have a more robust model
     #           under perturbations
@@ -382,7 +398,6 @@ def compute_dynamics_prec_opt(
     else:
         t_desired = t_stop - step_back
 
-
     idx_close = np.argmin(np.abs(ts - t_desired))
     t_fine = ts[idx_close:]
     dyn_fine = np.c_[t_fine, dyn[idx_close:]]
@@ -395,35 +410,30 @@ def compute_dynamics_prec_opt(
         t_peak = t_fine[idx_max]
 
         if idx_max != len(omega_fine):
-            omega_idxm1 = omega_fine[idx_max-1]
-            t_idxm1 = t_fine[idx_max-1]
+            omega_idxm1 = omega_fine[idx_max - 1]
+            t_idxm1 = t_fine[idx_max - 1]
 
             omega_idx0 = omega_peak
             t_idx0 = t_fine[idx_max]
 
-            omega_idx1 = omega_fine[idx_max+1]
-            t_idx1 = t_fine[idx_max+1]
+            omega_idx1 = omega_fine[idx_max + 1]
+            t_idx1 = t_fine[idx_max + 1]
 
-
-            t_peak, omega_peak = parabolaExtrema(omega_idx0,
-                                                 omega_idxm1,
-                                                 omega_idx1,
-                                                 t_idx0,
-                                                 t_idxm1,
-                                                 t_idx1
+            t_peak, omega_peak = parabolaExtrema(
+                omega_idx0, omega_idxm1, omega_idx1, t_idx0, t_idxm1, t_idx1
             )
 
     if peak_pr:
         intrp = CubicSpline(t_fine, dyn_fine[:, 3])
         left = t_fine[-1] - 10
         right = t_fine[-1]
-        t_peak = iterative_refinement(intrp.derivative(), [left, right], pr = True)
+        t_peak = iterative_refinement(intrp.derivative(), [left, right], pr=True)
 
     t_roll, dyn_roll, omega_roll = ts, dyn, omega_eob
     res = np.c_[t_roll, dyn_roll, omega_roll]
 
     if peak_omega or peak_pr:
-        t_start = max(t_peak - step_back,dyn_fine[0,0])
+        t_start = max(t_peak - step_back, dyn_fine[0, 0])
         idx_fine_start = np.argmin(np.abs(t_roll - t_start))
 
         idx_close = idx_fine_start
@@ -432,8 +442,9 @@ def compute_dynamics_prec_opt(
         dyn_fine = np.c_[t_fine, dyn_roll[idx_close:]]
         omega_fine = omega_roll[idx_close:]
 
-
-    t_roll, dyn_roll, omega_roll, idx_close = transition_dynamics_v2(ts, dyn, omega_eob, idx_close)
+    t_roll, dyn_roll, omega_roll, idx_close = transition_dynamics_v2(
+        ts, dyn, omega_eob, idx_close
+    )
 
     t_fine = t_roll[idx_close:]
     dyn_fine = np.c_[t_fine, dyn_roll[idx_close:]]
@@ -442,24 +453,19 @@ def compute_dynamics_prec_opt(
     dynamics_low = np.c_[t_roll[:idx_close], dyn_roll[:idx_close]]
     omega_low = omega_roll[:idx_close]
 
-
     # Add LN to the array so that it is also interpolated onto the fine sampling rate dynamics
-    dyn_fine = interpolate_dynamics(
-        dyn_fine, peak_omega=t_peak, step_back=step_back
-    )
-
-
+    dyn_fine = interpolate_dynamics(dyn_fine, peak_omega=t_peak, step_back=step_back)
 
     # Remove points where omega starts decreasing as we need it
     # to be monotonically increasing as it is used for interpolation
 
-    omega_dyn = dyn_fine[:,6]
+    omega_dyn = dyn_fine[:, 6]
     om_diff = np.diff(omega_dyn)
-    idx_omdiff = np.where(om_diff<0)[0]
+    idx_omdiff = np.where(om_diff < 0)[0]
 
-    if idx_omdiff.size !=0:
+    if idx_omdiff.size != 0:
         idx_final = idx_omdiff[0]
-        dyn_fine = dyn_fine[:idx_final+1]
+        dyn_fine = dyn_fine[: idx_final + 1]
 
     # Define the dynamics
     dynamics_fine = dyn_fine
@@ -467,29 +473,25 @@ def compute_dynamics_prec_opt(
     # Full dynamics array
     dynamics = np.vstack((dynamics_low, dynamics_fine))
 
-
-
     # Return EOB dynamics, LN vectors,  PN stuff
-    return (
-        dynamics_low,
-        dynamics_fine,
-        dynamics,
-        idx_close
-    )
+    return (dynamics_low, dynamics_fine, dynamics, idx_close)
 
-def transition_dynamics_v2(ts: np.ndarray, dyn: np.ndarray, omega_eob: np.ndarray, idx_restart:int):
+
+def transition_dynamics_v2(
+    ts: np.ndarray, dyn: np.ndarray, omega_eob: np.ndarray, idx_restart: int
+):
     """
-       Function to transition from a point dyn1,t1final to a point (dyn2,tfinal2)
+    Function to transition from a point dyn1,t1final to a point (dyn2,tfinal2)
 
-       Args:
+    Args:
 
-            ts (np.ndarray): Time array
-            dyn (np.ndarray): Dynamics array  (r,phi,pr,pphi)
-            omega_eob (np.ndarray): Orbital frequency array
-            idx_restart (int): Index which separates the low sampling rate dynamics and the high sampling rate dynamics.
+         ts (np.ndarray): Time array
+         dyn (np.ndarray): Dynamics array  (r,phi,pr,pphi)
+         omega_eob (np.ndarray): Orbital frequency array
+         idx_restart (int): Index which separates the low sampling rate dynamics and the high sampling rate dynamics.
 
-       Returns:
-            (tuple): Time array, dynamics, orbital frequency and index splitting the low and high sampling rate dynamics
+    Returns:
+         (tuple): Time array, dynamics, orbital frequency and index splitting the low and high sampling rate dynamics
     """
 
     # If the closest point within step back is actually the last point, step back more
@@ -535,7 +537,9 @@ def transition_dynamics_v2(ts: np.ndarray, dyn: np.ndarray, omega_eob: np.ndarra
         dyn_window = dyn[idx_restart - window : idx_restart + window]
 
         dyn_interp = CubicSpline(t_middle, dyn_window[:, :])
-        omega_interp = CubicSpline(t_middle, omega_eob[idx_restart - window : idx_restart + window])
+        omega_interp = CubicSpline(
+            t_middle, omega_eob[idx_restart - window : idx_restart + window]
+        )
 
         dyn_middle = dyn_interp(t_new)
         omega_middle = omega_interp(t_new)
@@ -544,11 +548,13 @@ def transition_dynamics_v2(ts: np.ndarray, dyn: np.ndarray, omega_eob: np.ndarra
         omega_low = omega_eob[:idx_restart]
         omega_fine = omega_eob[idx_restart:]
 
-        time = np.concatenate((t_low,t_new[:-1],t_fine))
-        dynamics = np.vstack((dyn_low, dyn_middle[:-1,:], dyn_fine))
-        omega = np.concatenate((omega_low,omega_middle[:-1],omega_fine))
+        time = np.concatenate((t_low, t_new[:-1], t_fine))
+        dynamics = np.vstack((dyn_low, dyn_middle[:-1, :], dyn_fine))
+        omega = np.concatenate((omega_low, omega_middle[:-1], omega_fine))
 
-        idx_restart_v1 =  len(omega_low)+len(omega_middle)-1 #idx_restart -1  + window_length
+        idx_restart_v1 = (
+            len(omega_low) + len(omega_middle) - 1
+        )  # idx_restart -1  + window_length
     else:
 
         dynamics = dyn
@@ -559,12 +565,8 @@ def transition_dynamics_v2(ts: np.ndarray, dyn: np.ndarray, omega_eob: np.ndarra
     return time, dynamics, omega, idx_restart_v1
 
 
-def parabolaExtrema(ff0:float,
-                    ffm1:float,
-                    ff1:float,
-                    tt0:float,
-                    ttm1:float,
-                    tt1:float
+def parabolaExtrema(
+    ff0: float, ffm1: float, ff1: float, tt0: float, ttm1: float, tt1: float
 ):
     """
     Compute the extremum of a parabola from 3 points (idx-1, idx, idx+1).
@@ -581,18 +583,26 @@ def parabolaExtrema(ff0:float,
         tuple: time of the extremum, and value of the function at the extremum
     """
 
-    aa = (ffm1*(tt0 - tt1) + ff0*(tt1 - ttm1) + ff1*(-tt0 + ttm1))/((tt0 - tt1)*(tt0 - ttm1)*(tt1 - ttm1))
-    bb = (ffm1*(-tt0*tt0 + tt1*tt1) + ff1*(tt0*tt0  -ttm1*ttm1) + ff0*(-tt1*tt1 + ttm1*ttm1))/((tt0 - tt1)*(tt0 - ttm1)*(tt1 - ttm1))
-    cc = (ffm1*tt0*(tt0 - tt1)*tt1 + ff0*tt1*(tt1 - ttm1)*ttm1 + ff1*tt0*ttm1*(-tt0 + ttm1))/((tt0 - tt1)*(tt0 - ttm1)*(tt1 - ttm1))
+    aa = (ffm1 * (tt0 - tt1) + ff0 * (tt1 - ttm1) + ff1 * (-tt0 + ttm1)) / (
+        (tt0 - tt1) * (tt0 - ttm1) * (tt1 - ttm1)
+    )
+    bb = (
+        ffm1 * (-tt0 * tt0 + tt1 * tt1)
+        + ff1 * (tt0 * tt0 - ttm1 * ttm1)
+        + ff0 * (-tt1 * tt1 + ttm1 * ttm1)
+    ) / ((tt0 - tt1) * (tt0 - ttm1) * (tt1 - ttm1))
+    cc = (
+        ffm1 * tt0 * (tt0 - tt1) * tt1
+        + ff0 * tt1 * (tt1 - ttm1) * ttm1
+        + ff1 * tt0 * ttm1 * (-tt0 + ttm1)
+    ) / ((tt0 - tt1) * (tt0 - ttm1) * (tt1 - ttm1))
 
-
-    textremum = -bb/(2.*aa)
-    ff_extremum = aa*textremum*textremum + bb*textremum + cc
+    textremum = -bb / (2.0 * aa)
+    ff_extremum = aa * textremum * textremum + bb * textremum + cc
 
     return textremum, ff_extremum
 
 
-
 def compute_dynamics_quasiprecessing(
     omega_ref: float,
     omega_start: float,
@@ -643,10 +653,10 @@ def compute_dynamics_quasiprecessing(
 
     # Step 1: Compute PN dynamics
 
-    if initial_conditions =="postadiabatic":
+    if initial_conditions == "postadiabatic":
 
         combined_t, combined_y = compute_quasiprecessing_PNdynamics_opt(
-            omega_ref, 0.9*omega_start, m_1, m_2, chi_1, chi_2
+            omega_ref, 0.9 * omega_start, m_1, m_2, chi_1, chi_2
         )
     else:
 
@@ -661,13 +671,7 @@ def compute_dynamics_quasiprecessing(
     splines = build_splines_PN(combined_t, combined_y, m_1, m_2, omega_start)
 
     # Step 3: Evolve the non-precessing EOB evolution equations
-    (
-
-        dynamics_low,
-        dynamics_fine,
-        dynamics,
-        idx_restart
-    ) = compute_dynamics_prec_opt(
+    (dynamics_low, dynamics_fine, dynamics, idx_restart) = compute_dynamics_prec_opt(
         omega_ref,
         omega_start,
         omegaPN_f,
@@ -694,5 +698,5 @@ def compute_dynamics_quasiprecessing(
         combined_y,
         splines,
         dynamics,
-        idx_restart
+        idx_restart,
     )
